=== modified file 'NEWS'
--- NEWS	2006-02-15 22:01:55 +0000
+++ NEWS	2006-02-16 16:43:07 +0000
@@ -31,6 +31,11 @@
       locally. As such they are not suitable for use except in high bandwidth
       low latency environments like LAN's or local disk. (Robert Collins)
 
+    * Default log format can be set in configuration and plugins can register
+      their own formatters. (Erik Bågfors)
+
+    * pull now accepts a --revision argument (Erik Bågfors)
+
   INTERNALS:
   
     * The internal storage of history, and logical branch identity have now
@@ -43,11 +48,6 @@
     * SFTP tests now shortcut the SSH negotiation, reducing test overhead
       for testing SFTP protocol support. (Robey Pointer)
 
-  IMPROVEMENTS:
-
-    * pull now accepts a --revision argument (Erik Bågfors)
-
-
 bzr 0.7rc1 2006-01-09
 
   CHANGES:

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2006-02-15 22:01:55 +0000
+++ bzrlib/builtins.py	2006-02-16 16:43:07 +0000
@@ -971,6 +971,7 @@
                             help='show from oldest to newest'),
                      'timezone', 'verbose', 
                      'show-ids', 'revision',
+                     'log-format',
                      'line', 'long', 
                      Option('message',
                             help='show revisions whose message matches this regexp',
@@ -983,6 +984,7 @@
             show_ids=False,
             forward=False,
             revision=None,
+            log_format=None,
             message=None,
             long=False,
             short=False,
@@ -1041,7 +1043,10 @@
         # in e.g. the default C locale.
         outf = codecs.getwriter(bzrlib.user_encoding)(sys.stdout, errors='replace')
 
-        log_format = get_log_format(long=long, short=short, line=line)
+        if (log_format == None):
+            default = bzrlib.config.BranchConfig(b).log_format()
+            log_format = get_log_format(long=long, short=short, line=line, default=default)
+
         lf = log_formatter(log_format,
                            show_ids=show_ids,
                            to_file=outf,
@@ -1893,6 +1898,7 @@
                             'Display changes in the local branch only'),
                      Option('theirs-only', 
                             'Display changes in the remote branch only'), 
+                     'log-format',
                      'line',
                      'long', 
                      'short',
@@ -1901,7 +1907,7 @@
                      ]
 
     def run(self, other_branch=None, reverse=False, mine_only=False,
-            theirs_only=False, long=True, short=False, line=False, 
+            theirs_only=False, log_format=None, long=False, short=False, line=False, 
             show_ids=False, verbose=False):
         from bzrlib.missing import find_unmerged, iter_log_data
         from bzrlib.log import log_formatter
@@ -1914,7 +1920,9 @@
             print "Using last location: " + local_branch.get_parent()
         remote_branch = bzrlib.branch.Branch.open(other_branch)
         local_extra, remote_extra = find_unmerged(local_branch, remote_branch)
-        log_format = get_log_format(long=long, short=short, line=line)
+        if (log_format == None):
+            default = bzrlib.config.BranchConfig(local_branch).log_format()
+            log_format = get_log_format(long=long, short=short, line=line, default=default)
         lf = log_formatter(log_format, sys.stdout,
                            show_ids=show_ids,
                            show_timezone='original')

=== modified file 'bzrlib/config.py'
--- bzrlib/config.py	2006-01-25 01:43:34 +0000
+++ bzrlib/config.py	2006-02-10 21:23:29 +0000
@@ -27,6 +27,7 @@
 check_signatures=require|ignore|check-available(default)
 create_signatures=always|never|when-required(default)
 gpg_signing_command=name-of-program
+log_format=name-of-format
 
 in branches.conf, you specify the url of a branch and options for it.
 Wildcards may be used - * and ? as normal in shell completion. Options
@@ -49,6 +50,8 @@
                     gpg signatures, never create them, or create them if the
                     branch is configured to require them.
                     NB: This option is planned, but not implemented yet.
+log_format - This options set the default log format.  Options are long, 
+             short, line, or a plugin can register new formats
 """
 
 
@@ -120,6 +123,17 @@
         """See gpg_signing_command()."""
         return None
 
+    def log_format(self):
+        """What log format should be used"""
+        result = self._log_format()
+        if result is None:
+            result = "long"
+        return result
+
+    def _log_format(self):
+        """See log_format()."""
+        return None
+
     def __init__(self):
         super(Config, self).__init__()
 
@@ -226,6 +240,10 @@
         """See Config.gpg_signing_command."""
         return self._get_user_option('gpg_signing_command')
 
+    def _log_format(self):
+        """See Config.log_format."""
+        return self._get_user_option('log_format')
+
     def __init__(self, get_filename):
         super(IniBasedConfig, self).__init__()
         self._get_filename = get_filename
@@ -318,6 +336,13 @@
             return command
         return self._get_global_config()._gpg_signing_command()
 
+    def _log_format(self):
+        """See Config.log_format."""
+        command = super(LocationConfig, self)._log_format()
+        if command is not None:
+            return command
+        return self._get_global_config()._log_format()
+
     def _get_user_id(self):
         user_id = super(LocationConfig, self)._get_user_id()
         if user_id is not None:
@@ -409,6 +434,9 @@
         """See Config.post_commit."""
         return self._get_location_config()._post_commit()
 
+    def _log_format(self):
+        """See Config.log_format."""
+        return self._get_location_config()._log_format()
 
 def ensure_config_dir_exists(path=None):
     """Make sure a configuration directory exists.

=== modified file 'bzrlib/log.py'
--- bzrlib/log.py	2005-12-25 00:38:48 +0000
+++ bzrlib/log.py	2006-02-04 11:36:23 +0000
@@ -450,11 +450,14 @@
     lf = LineLogFormatter(None)
     return lf.log_string(rev, max_chars)
 
-FORMATTERS = {'long': LongLogFormatter,
+FORMATTERS = {
+              'long': LongLogFormatter,
               'short': ShortLogFormatter,
               'line': LineLogFormatter,
               }
 
+def register_formatter(name, formatter):
+    FORMATTERS[name] = formatter
 
 def log_formatter(name, *args, **kwargs):
     """Construct a formatter from arguments.
@@ -465,7 +468,7 @@
     from bzrlib.errors import BzrCommandError
     try:
         return FORMATTERS[name](*args, **kwargs)
-    except IndexError:
+    except KeyError:
         raise BzrCommandError("unknown log formatter: %r" % name)
 
 def show_one_log(revno, rev, delta, verbose, to_file, show_timezone):

=== modified file 'bzrlib/option.py'
--- bzrlib/option.py	2006-01-17 15:31:21 +0000
+++ bzrlib/option.py	2006-02-03 19:50:59 +0000
@@ -184,9 +184,10 @@
 _global_option('version')
 _global_option('email')
 _global_option('update')
-_global_option('long', help='Use detailed log format')
-_global_option('short', help='Use moderately short log format')
-_global_option('line', help='Use log format with one line per revision')
+_global_option('log-format', type=str, help="Use this log format")
+_global_option('long', help='Use detailed log format. Same as --log-format long')
+_global_option('short', help='Use moderately short log format. Same as --log-format short')
+_global_option('line', help='Use log format with one line per revision. Same as --log-format line')
 _global_option('root', type=str)
 _global_option('no-backup')
 _global_option('merge-type', type=_parse_merge_type)

=== modified file 'bzrlib/tests/blackbox/__init__.py'
--- bzrlib/tests/blackbox/__init__.py	2006-02-15 22:01:55 +0000
+++ bzrlib/tests/blackbox/__init__.py	2006-02-16 16:43:07 +0000
@@ -41,6 +41,7 @@
                      'bzrlib.tests.blackbox.test_export',
                      'bzrlib.tests.blackbox.test_find_merge_base',
                      'bzrlib.tests.blackbox.test_log',
+                     'bzrlib.tests.blackbox.test_logformats',
                      'bzrlib.tests.blackbox.test_missing',
                      'bzrlib.tests.blackbox.test_outside_wt',
                      'bzrlib.tests.blackbox.test_pull',

=== added file 'bzrlib/tests/blackbox/test_logformats.py'
--- bzrlib/tests/blackbox/test_logformats.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/blackbox/test_logformats.py	2006-02-16 10:43:59 +0000
@@ -0,0 +1,111 @@
+"""Black-box tests for default log_formats/log_formatters
+"""
+
+import os
+
+from bzrlib.branch import Branch
+from bzrlib.tests import TestCaseInTempDir
+from bzrlib.config import (config_dir, config_filename)
+
+
+class TestLogFormats(TestCaseInTempDir):
+
+    def bzr(self, *args, **kwargs):
+        return self.run_bzr(*args, **kwargs)[0]
+
+    def test_log_default_format(self):
+        setup_config()
+
+        self.bzr('init')
+        open('a', 'wb').write('foo\n')
+        self.bzr('add', 'a')
+
+        self.bzr('commit', '-m', '1')
+        open('a', 'wb').write('baz\n')
+
+        self.bzr('commit', '-m', '2')
+
+        # only the lines formatter is this short
+        self.assertEquals(3, len(self.bzr('log').split('\n')))
+
+    def test_log_format_arg(self):
+        self.bzr('init')
+        open('a', 'wb').write('foo\n')
+        self.bzr('add', 'a')
+
+        self.bzr('commit', '-m', '1')
+        open('a', 'wb').write('baz\n')
+
+        self.bzr('commit', '-m', '2')
+
+        # only the lines formatter is this short
+        self.assertEquals(7, len(self.bzr('log', '--log-format', 'short').split('\n')))
+
+    def test_missing_default_format(self):
+        setup_config()
+
+        os.mkdir('a')
+        os.chdir('a')
+        self.bzr('init')
+
+        open('a', 'wb').write('foo\n')
+        self.bzr('add', 'a')
+        self.bzr('commit', '-m', '1')
+
+        os.chdir('..')
+        self.bzr('branch', 'a', 'b')
+        os.chdir('a')
+
+        open('a', 'wb').write('bar\n')
+        self.bzr('commit', '-m', '2')
+
+        open('a', 'wb').write('baz\n')
+        self.bzr('commit', '-m', '3')
+
+        os.chdir('../b')
+        
+        self.assertEquals(5, len(self.bzr('missing', retcode=1).split('\n')))
+        
+        os.chdir('..')
+
+    def test_missing_format_arg(self):
+        setup_config()
+
+        os.mkdir('a')
+        os.chdir('a')
+        self.bzr('init')
+
+        open('a', 'wb').write('foo\n')
+        self.bzr('add', 'a')
+        self.bzr('commit', '-m', '1')
+
+        os.chdir('..')
+        self.bzr('branch', 'a', 'b')
+        os.chdir('a')
+
+        open('a', 'wb').write('bar\n')
+        self.bzr('commit', '-m', '2')
+
+        open('a', 'wb').write('baz\n')
+        self.bzr('commit', '-m', '3')
+
+        os.chdir('../b')
+        
+        self.assertEquals(9, len(self.bzr('missing', '--log-format', 'short', retcode=1).split('\n')))
+        
+        os.chdir('..')
+
+
+def setup_config():
+        if os.path.isfile(config_filename()):
+                # Something is wrong in environment, 
+                # we risk overwriting users config 
+                self.assert_(config_filename() + "exists, abort")
+            
+        os.mkdir(config_dir())
+        CONFIG=("[DEFAULT]\n"
+                "email=Joe Foo <joe@foo.com>\n"
+                "log_format=line\n")
+
+        open(config_filename(),'wb').write(CONFIG)
+

=== modified file 'bzrlib/tests/test_config.py'
--- bzrlib/tests/test_config.py	2006-01-25 01:43:34 +0000
+++ bzrlib/tests/test_config.py	2006-02-10 21:23:29 +0000
@@ -32,6 +32,7 @@
                       "email=Robert Collins <robertc@example.com>\n"
                       "editor=vim\n"
                       "gpg_signing_command=gnome-gpg\n"
+                      "log_format=short\n"
                       "user_global_option=something\n")
 
 
@@ -176,6 +177,10 @@
         my_config = config.Config()
         self.assertEqual(None, my_config.post_commit())
 
+    def test_log_format_default(self):
+        my_config = config.Config()
+        self.assertEqual('long', my_config.log_format())
+
 
 class TestConfigPath(TestCase):
 
@@ -352,6 +357,10 @@
         my_config = self._get_sample_config()
         self.assertEqual(None, my_config.post_commit())
 
+    def test_configured_logformat(self):
+        my_config = self._get_sample_config()
+        self.assertEqual("short", my_config.log_format())
+
 
 class TestLocationConfig(TestCase):
 

